import mysql, { Connection } from 'mysql2/promise';
import dotenv from 'dotenv';

dotenv.config();

const { DB_URI, USER, PW, DB_NAME } = process.env;

export default abstract class DatabaseConfig{

    static mysqlCon: Connection;
    private static promiseResolve: (val?: any) => void;
    private static dbReady: any = null;

    constructor(){
        if(!DatabaseConfig.dbReady){
            DatabaseConfig.dbReady = new Promise((resolve) => {DatabaseConfig.promiseResolve = resolve});
            this.initDb();
        }
    }

    async initDb(){
        DatabaseConfig.mysqlCon = await mysql.createConnection({
            host: DB_URI,
            user: USER,
            password: PW,
            database: DB_NAME
        });

        DatabaseConfig.mysqlCon.connect().then(() => {
            DatabaseConfig.promiseResolve();
        });
    }

    async dbIsReady(): Promise<Connection>{
        return DatabaseConfig.dbReady;
    }
}