import AuthService from "../services/authService";
import jwt from "jsonwebtoken";

const express = require("express");

const router = express.Router();

const authService = new AuthService();

router.post("/", (req: any, res: any) => {
    let token = req.headers['authorization'];

    try {
        token = token.split(' ')[1];

        if (!authService.validateToken(token)) {
            throw new Error();
        };

        return res;
    } catch (e) {
        return res.status(401).send("Unauthorized, invalid Token!");
    }
})

router.post("/refresh", async (req: any, res: any) => {
    try {
        const token = req.cookies['refresh-jwt'];

        const data = authService.validateToken(token) as jwt.JwtPayload;

        if (data) {
            const accessToken = authService.generateToken(data['user_id'], data['user_email']);
            const refreshToken = authService.generateRefreshToken(data['user_email']);

            // Assigning refresh token in http-only cookie 
            res.cookie('refresh-jwt', refreshToken, {
                httpOnly: true,
                sameSite: 'None', secure: true,
                maxAge: 24 * 60 * 60 * 1000
            });

            return res.send(accessToken);
        }

    } catch (e) { }
    
    return res.sendStatus(401);
})

export default router;