import User from "../model/user";
import AuthService from "../services/authService";
import UserService from "../services/userService";

const express = require("express");

const router = express.Router();

const userService = new UserService();

router.post("/register", async (req: any, res: any) => {
    try {
        const user = req.body;
        const userEntity = new User(user.id, user.name, user.email, user.password);

        // Our register logic starts here
        return res.send(await userService.registerUser(userEntity));
    } catch (e: any) {
        return res.status(400).send(e);
    }
})

router.post("/login", async (req: any, res: any) => {
    try {
        const [jwt, refreshToken] = await userService.loginUser(req.body);

        if(refreshToken){
            // Assigning refresh token in http-only cookie 
            res.cookie('refresh-jwt', refreshToken, {
                httpOnly: true,
                sameSite: 'None', secure: true,
                maxAge: 24 * 60 * 60 * 1000
            });
        }

        return res.send(jwt);
    } catch (e: any) {
        if(e.message.includes("invalid")){
            return res.send(401, e.message);
        } else if(e.message.includes("not found")){
            return res.send(404, e.message);
        }
        return res.send(500, e.message);
    }
})

router.delete("/:id", (req: any, res: any) => {
    try {
        const id = req.params.id;
        return res.send(userService.delete(id));
    } catch (e) {
        return res.send(e);
    }
})

router.get("/", async (req: any, res: any) => {
    return res.send(await userService.getAllUser());
})

export default router;