import User from "../model/user";
import DbService from "./dbService";
import AuthService from "./authService";

export default class UserService {

    private USER_TABLE = "users";
    private dbService: DbService;
    private authService: AuthService;

    constructor() {
        this.dbService = new DbService(this.USER_TABLE);
        this.authService = new AuthService();
    }

    async getUser(id: number) {
        return this.dbService.get(id);
    }

    async getUserByEmail(email: string) {
        return this.dbService.customQuery(`SELECT * FROM ${this.USER_TABLE} WHERE email = ?`, [email]);
    }

    async getAllUser() {
        try {
            const [res, fields] = await this.dbService.getAll();
            return res;
        } catch (e) {

        }
    }

    async registerUser(user: User) {
        try {
            const [rows, fields] = await this.dbService.customQuery(`SELECT * FROM ${this.USER_TABLE} WHERE email = ?`, [user.getEmail()]);

            if (rows.length) {
                throw Error("User already exists!");
            }

            user.hashPassword(user.getPassword());

            const [saveRows, saveFields] = await this.dbService.save(user);
            const regUser = saveRows

            if (!regUser) {
                throw Error("Did not register User!");
            }

            // Create token
            return this.authService.generateToken(user.getId()!, user.getEmail());

        } catch (e) {
            throw e;
        }
    }

    async loginUser(user: any){
        const [rows, fields] = await this.getUserByEmail(user.email);
        
        if (rows.length) {
            const userEntity = new User(rows[0].id, rows[0].name, rows[0].email, rows[0].password);

            if(userEntity.checkPassword(user.password)){
                const accessToken = this.authService.generateToken(rows[0].id,rows[0].email);
                const refreshToken = this.authService.generateRefreshToken(rows[0].email);
    
                return [accessToken, refreshToken];
            }

            throw new Error("User credentials invalid!")
        }

        throw new Error("User not found");
    }

    async delete(id: number) {
        try {
            return this.dbService.delete(id);
        } catch (e) {
            throw e;
        }
    }
}